Learn R Programming

oceanmap (version 0.1.0)

close_fig: function to close current graphic device

Description

function to close current graphic device, complement to figure-function that generates graphic devices in flexible fileformats.

Usage

close_fig(do.close=F, do.save=do.close)

Arguments

do.close, do.save

whether file should be saved or not (default is TRUE). if FALSE, new graphic device will be opened inside R.

See Also

figure

Examples

Run this code
# NOT RUN {
do.save <- TRUE
figure("Gulf_of_Lions", do.save=do.save, width=5, height=5, type="pdf")
plotmap("lion")
close_fig(do.save)

plotmap("lion")
close_fig(do.save)

do.save <- FALSE
figure("Gulf_of_Lions", do.save=do.save, width=5, height=5, type="pdf")
plotmap("lion")
close_fig(do.save)

# }

Run the code above in your browser using DataLab