powered by
Creates an empty scatter plot that is equal to the function call:
plot(1,lwd=0,axes=F,xlab="",ylab="",...)
empty.plot(..., xlab = "", ylab = "", new=T, add=!new, n=1, axes = F)
other arguments of the generic x-y plotting fucntion plot.
label for the x- and y-axis of the plot (default is empty).
whether to show add plot to a current plot device or to start a new figure (default is: new=TRUE and add=FALSE).
TRUE
FALSE
number of figures to be plotted (default is 1)
whether to show plot axes (default is FALSE).
# NOT RUN { empty.plot() title("empty plot") box() axis(1) axis(2) # }
Run the code above in your browser using DataLab