a dataframe with the following header, containing definitions of parameters to plot or to save by v, readbin and writebin:
param a b c log name1 unit pal1 minv maxv min max invalid_data_dc coast_dc land_dc no_data_dc
paramcharacter string indicating the keyword of a parameter.
a,b,cvalue for parameter parameter data conversion from/to byte data. (See param_convert and param_unconvert)
logwhether a logarithmic formula should be applied for data conversion (0 for FALSE and 1 for TRUE; See param_convert and param_unconvert).
namecharacter string indicating the long name of a parameter.
unitcharacter string or bgroup statement indicating the parameter unit.
pal1default color map used by v calls on parameter related data.
minv, maxvdefault minimum and maximum z-value used by v calls on parameter related data.
min, maxminimum and maximum byte-values to be considered when calculating absolute values.
invalid_data_dc, coast_dc, land_dc & no_data_dcbyte values used to mask invalid data, coast lines, land masses and missing data.