a two-row dataframe with the following header, containing the summary information of the region specified:
xlim ylim dim name cbx cby align gradient figdim grid.res
xlim & ylimthe spatial extent of the region
dimthe number of grid points for both x & y-dimension
namethe long name of the region
cbx & cbyx & y-coordinates for colorbar
aligna vector defining the color-gradient of the colorbar (x for horizontal, and y for vertical), as well as the margin where the colorbar ticks should be plotted, relative to the colorbar rectangle ('l' left, 'r' right and 'b' for bottom)
figdimthe region-specific default plot device size
grid.resthe default grid resolution in degrees